SwaggerMethod class

Constructors

SwaggerMethod({required String operationId, required String httpMethod, required String path, required List<SwaggerParam> parameters, required SwaggerParam? bodyParam, required SwaggerType returnType, required int defaultStatusCode, required bool isHidden, required List<SwaggerExplicitResponse> explicitResponses, String? summary, String? description, List<String> tags = const []})
SwaggerMethod.fromMeta(MetaMethod method, String controllerName, SchemaRegistry registry)
factory

Properties

bodyParam SwaggerParam?
final
defaultStatusCode int
final
description String?
final
explicitResponses List<SwaggerExplicitResponse>
final
hashCode int
The hash code for this object.
no setterinherited
httpMethod String
final
isHidden bool
final
operationId String
final
parameters List<SwaggerParam>
final
path String
final
returnType SwaggerType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String?
final
tags List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited