SwaggerServer class

Constructors

SwaggerServer({required List<SwaggerController> controllers, required SwaggerInfo info})
SwaggerServer.fromMeta(RevaliContext context, MetaServer server, SwaggerSettings settings, SchemaRegistry registry)
factory

Properties

controllers List<SwaggerController>
final
hashCode int
The hash code for this object.
no setterinherited
info SwaggerInfo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleControllers Iterable<SwaggerController>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited