SwaggerParam class
Constructors
- SwaggerParam({required String name, required ParamLocation location, required SwaggerType type, required bool isRequired, String? wireName})
Properties
- effectiveName → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBody → bool
-
no setter
- isRequired → bool
-
final
- location → ParamLocation
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → SwaggerType
-
final
- wireName → String?
-
Override name from annotation (e.g. @Query('page_size') → 'page_size').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMeta(
MetaParam param, SchemaRegistry registry) → SwaggerParam?